#!/usr/bin/env python
import sys
import numpy
import pylab
import matplotlib.pyplot as plt
import matplotlib

def main():
        
        title = 'KINK benchmark'
        xlabel = 'resistivity [Ohm.m]'
        ylabel = 'growth-rate [s$^{-1}$]'
        xlog   = 'true'
        rho0 = 1.0e20 * 2 * 1.6726219e-27

        # --- Normalisation
        mu0  = 1.256637062e-6
        t_norm = (rho0*mu0)**0.5

        # --- Prepare plots
        matplotlib.rcParams.update({'font.size': 18})
        matplotlib.rcParams.update({'font.weight': 'bold'})
        matplotlib.rcParams.update({'legend.fontsize': 18})
        fig = plt.figure()
        ax1 = fig.add_subplot(111)

        # --- Show plot
        filename = 'gammas_ers.dat'
        plot_profile(filename, ax1, 1.0, 'pb')
        filename = 'growth_rates_kink_303.txt'
        plot_profile(filename, ax1, t_norm, 'ks')
        filename = 'growth_rates_kink.txt'
        plot_profile(filename, ax1, t_norm, 'rv')
        
        xxx = numpy.linspace(1.e-15,1.e0,200)
        yyy = numpy.zeros(200)
        fact = 2.2e5
        for i in range(200):
          yyy[i] = fact*xxx[i]**(1.0/3.0)
        ax1.plot(xxx,yyy,'k--',linewidth=2)
        
        pylab.xlabel(xlabel)
        pylab.ylabel(ylabel)
        pylab.title(title)
        pylab.legend(['CASTOR','RMHD','FMHD','\nscaling $\eta^{1/3}$'], loc=2)
        if (xlog == 'true'):
          pylab.xscale("log")
        pylab.yscale("log")
        pylab.show()


def plot_profile(filename, ax1, t_norm, my_col):
 
        #----Initialise----
        file_tmp = open(filename, 'r')
        xxx = numpy.array([])
        yyy1 = numpy.array([])
        for line in file_tmp:
            array_tmp = line.split()
            if (len(array_tmp) == 0): continue
            if (array_tmp[0] == '#'): continue
            xxx  = numpy.append(xxx,  float(array_tmp[0]))
            yyy1 = numpy.append(yyy1, float(array_tmp[1]))
        ax1.plot(xxx,yyy1/t_norm,my_col,linewidth=2,ms=12)
        file_tmp.close()


main()
